class TimeCodeErrors:
    INVALID_TC_ERR = "Invalid timecode format:"
    INVALID_RESULTANT_TC_ERR = "Resultant timecode is invalid:"
    INVALID_DURATION_ERR = "The duration must be positive."
    INVALID_FPS_ERR = "The FPS must be positive."
    INVALID_FRAME_ERR = "The number of frames must be a non-negative integer."
